@@ -33,6 +33,7 @@
 """|UDM| module for |UDM| properties"""
 
 from logging import getLogger
+from typing import Any  # noqa: F401
 
 import univention.admin.filter
 import univention.admin.handlers
@@ -342,12 +343,14 @@ class object(univention.admin.handlers.simpleLdap):
     module = module
 
     def _ldap_pre_create(self):
+        # type: () -> None
         super(object, self)._ldap_pre_create()
 
         if 'users/user' in self['module'] and self['valueRequired'] == '1' and not self.info.get('default'):
             raise univention.admin.uexceptions.valueRequired(_('Extending the users module is only possible if a default value for a required value is given.'), property='default')
 
     def open(self):
+        # type: () -> None
         # univentionUDMPropertyTranslation;entry-de-de: Meine Kurzbeschreibung 9
         # univentionUDMPropertyTranslation;entry-en-gb: This is my short description9
 
@@ -366,6 +369,7 @@ class object(univention.admin.handlers.simpleLdap):
         self.save()
 
     def _ldap_modlist(self):
+        # type: () -> list[tuple[str, Any, Any]]
         # univentionUDMPropertyShortTranslation;entry-de-de: Meine Kurzbeschreibung 9
         # univentionUDMPropertyShortTranslation;entry-en-gb: This is my short description9
 
@@ -398,6 +402,7 @@ class object(univention.admin.handlers.simpleLdap):
 
     @classmethod
     def unmapped_lookup_filter(cls):
+        # type: () -> univention.admin.filter.conjunction
         return univention.admin.filter.conjunction('&', [
             univention.admin.filter.expression('objectClass', 'univentionUDMProperty'),
             univention.admin.filter.expression('univentionUDMPropertyVersion', '2'),
@@ -409,4 +414,5 @@ lookup_filter = object.lookup_filter
 
 
 def identify(dn, attr, canonical=False):
+    # type: (str, univention.admin.handlers._Attributes, bool) -> bool
     return b'univentionUDMProperty' in attr.get('objectClass', []) and attr.get('univentionUDMPropertyVersion', [b'0'])[0] == b'2'
