@@ -131,7 +131,7 @@ class object(univention.admin.handlers.simpleLdap):
                     if len(member_list['univentionPrinterGroupMember']) < 2:
                         raise univention.admin.uexceptions.emptyPrinterGroup(_('%(name)s is the last member of the printer group %(group)s. ') % {'name': self.info['name'], 'group': member_list['cn'][0].decode('UTF-8')})
 
-        printergroup_module = univention.admin.modules.get('shares/printergroup')
+        printergroup_module = univention.admin.modules._get('shares/printergroup')
         for rm_dn in rm_attrib:
             printergroup_object = univention.admin.objects.get(printergroup_module, None, self.lo, position='', dn=rm_dn)
             printergroup_object.open()
